@@ -3,14 +3,22 @@ use strict;
 use warnings;
 package CPAN::Meta::Converter;
 BEGIN {
-  $CPAN::Meta::Converter::VERSION = '2.110550';
+  $CPAN::Meta::Converter::VERSION = '2.110580';
 }
 # ABSTRACT: Convert CPAN distribution metadata structures
 
 
 use CPAN::Meta::Validator;
-use Storable qw/dclone/;
 use version 0.82 ();
+use Parse::CPAN::Meta 1.4400 ();
+
+sub _dclone {
+  my $ref = shift;
+  my $backend = Parse::CPAN::Meta->json_backend();
+  return $backend->new->decode(
+    $backend->new->convert_blessed->encode($ref)
+  );
+}
 
 my %known_specs = (
     '2'   => 'http://search.cpan.org/perldoc?CPAN::Meta::Spec',
@@ -1187,7 +1195,7 @@ sub convert {
   my $new_version = $args->{version} || $HIGHEST;
 
   my ($old_version) = $self->{spec};
-  my $converted = dclone $self->{data};
+  my $converted = _dclone($self->{data});
 
   if ( $old_version == $new_version ) {
     $converted = _convert( $converted, $cleanup{$old_version}, $old_version );
@@ -1242,7 +1250,7 @@ CPAN::Meta::Converter - Convert CPAN distribution metadata structures
 
 =head1 VERSION
 
-version 2.110550
+version 2.110580
 
 =head1 SYNOPSIS
 
